@@ -7,9 +7,13 @@ from pgrunner.commands import get_port, CURRENT
 class Command(BaseCommand):
     help = 'Run pg_ctl with correct data dir'
 
-    def handle(self, *args, **options):
-        cmd = [bin_path('pg_ctl'), '-D', CURRENT]
-        cmd.extend(args)
+    def run_from_argv(self, argv):
+        pg_ctl = bin_path('pg_ctl')
+        if '--help' in argv:
+            cmd = [pg_ctl, '--help']
+        else:
+            cmd = [pg_ctl, '-D', CURRENT]
+            cmd.extend(argv[2:])
         print(' '.join(cmd))
         subprocess.call(cmd)
 
